4Suite API Documentation: Ft.Lib.TestSuite.TestCoverage

4Suite™ API Documentation

# ► Module Ft.Lib.TestSuite.TestCoverage

A class that uses Python's profiler to help TestModule know which functions have been called in a particular module.

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Classes: TestCoverage

## Classes

class TestCoverage

  ### Methods

  __init__(self, moduleName, ignored=None)